Steno3D
*******

.. image:: https://travis-ci.org/3ptscience/steno3dpy.svg?branch=master
    :target: https://travis-ci.org/3ptscience/steno3dpy

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: MIT License
    :target: https://github.com/3ptscience/steno3dpy/blob/master/LICENSE

.. image:: https://img.shields.io/badge/download-PyPI-yellow.svg
    :target: https://pypi.python.org/pypi/steno3d

.. image:: http://mybinder.org/badge.svg
    :target: http://mybinder.org/repo/3ptscience/steno3d-notebooks

Welcome to the Python client library for `Steno3D <https://www.steno3d.com>`_
by `3point Science <https://www.3ptscience.com>`_.

.. image:: https://raw.githubusercontent.com/3ptscience/steno3dpy/master/docs/images/steno3dpy_screenshot.png
    :width: 100%
    :align: center
    :alt: Steno3D in action
    :target: https://steno3d.com/

If you have not yet installed `Steno3D <https://www.steno3d.com>`_, simply

.. code:: bash

    pip install steno3d

You also need to `sign up for a Steno3D account <https://www.steno3d.com/signup>`_.
From there, you can `request a developer API key <https://www.steno3d.com/settings/developer>`_.

At that point, you can

.. code:: python

    import steno3d
    steno3d.login()

then start building your 3D project. API documentation is available on
`online <https://steno3d.com/docs>`_. Tutorials and
Examples are available as `Jupyter notebooks <https://github.com/3ptscience/steno3d-notebooks>`_.
Class documentation can also be accessed in the IPython environment
with `?` and tab completion.

The latest version of Steno3D is 0.2.14. Detailed release notes are available
on `github <https://github.com/3ptscience/steno3dpy/releases>`_.
